<?php

namespace Drupal\role_language_negotiation\Plugin\LanguageNegotiation;

use Drupal\language\LanguageNegotiationMethodBase;
use Drupal\Core\Language\LanguageInterface;
use Drupal\language\Plugin\LanguageNegotiation\LanguageNegotiationUrl;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class for identifying language depedning on the user role.
 *
 * @LanguageNegotiation(
 *   id = Drupal\role_language_negotiation\Plugin\LanguageNegotiation\LanguageNegotiationRole::METHOD_ID,
 *   weight = 50,
 *   name = @Translation("User role"),
 *   description = @Translation("Language based on the user role."),
 *   config_route_name = "role_language_negotiation.language.negotiation_role"
 * )
 */
class LanguageNegotiationRole extends LanguageNegotiationUrl {

  /**
   * The language negotiation method id.
   */
  const METHOD_ID = 'language-role';

  /**
   * {@inheritdoc}
   */
  public function getLangcode(Request $request = NULL) {
    $langcode = parent::getLangcode($request);
    $roles_languages = $this->config->get('role_language_negotiation.settings')->get('language_negotiation_roles');

    if ($this->languageManager && $roles_languages && $langcode) {
      foreach ($this->currentUser->getRoles() as $role_key => $role_value) {
        if ($roles_languages[$role_value]['enabled'] == "1") {
          if ($roles_languages[$role_value]['languages'][$langcode]['enabled'] == "1") {
            return $langcode;
          }
          else {
            foreach ($roles_languages[$role_value]['languages'] as $lang_key => $lang_value) {
              if ($lang_value['enabled'] == "1") {
                return $lang_key;
              }
            }
          }
        }
      }
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getLanguageSwitchLinks(Request $request, $type, Url $url) {
    $links = parent::getLanguageSwitchLinks($request, $type, $url);
    $roles_languages = $this->config->get('role_language_negotiation.settings')->get('language_negotiation_roles');

    $allowed_languages = [];
    foreach ($this->currentUser->getRoles() as $role_key => $role_value) {
      if ($roles_languages[$role_value]['enabled'] == "1") {
        foreach ($roles_languages[$role_value]['languages'] as $lang_key => $lang_value) {
          if ($lang_value['enabled'] == "1") {
            $allowed_languages[$lang_key] = $lang_key;
          }
        }
      }
    }

    return array_intersect_key($links, $allowed_languages);
  }

}
